@@ -1,6 +1,6 @@
 <?php
     /**
-     * Copyright (c) 2010-2014 Arne Blankerts <arne@blankerts.de>
+     * Copyright (c) 2010-2015 Arne Blankerts <arne@blankerts.de>
      * All rights reserved.
      *
      * Redistribution and use in source and binary forms, with or without modification,
@@ -120,7 +120,7 @@ namespace TheSeer\phpDox\Collector {
          * @return \DOMNodeList
          */
         public function findUnitNodesBySrcFile($path) {
-            $src = substr($path, strlen($this->srcDir) + 1);
+            $src = mb_substr($path, mb_strlen($this->srcDir) + 1);
             return $this->getRootElement()->query(sprintf('//*[@src="%s"]', $src));
         }
 
