@@ -1,6 +1,6 @@
 <?php
     /**
-     * Copyright (c) 2010-2014 Arne Blankerts <arne@blankerts.de>
+     * Copyright (c) 2010-2015 Arne Blankerts <arne@blankerts.de>
      * All rights reserved.
      *
      * Redistribution and use in source and binary forms, with or without modification,
@@ -43,7 +43,7 @@ namespace TheSeer\phpDox\Collector {
             if ($this->getRootNode()->queryOne(sprintf('phpdox:implementor[@full = "%s"]', $unit->getName())) !== NULL) {
                 return;
             }
-            $implementor = $this->getRootNode()->appendElementNS(self::XMLNS, 'implementor');
+            $implementor = $this->addToContainer('implementors', $unit->getType());
             $this->setName($unit->getName(), $implementor);
 
         }
