@@ -1,6 +1,6 @@
 <?php
     /**
-     * Copyright (c) 2010-2014 Arne Blankerts <arne@blankerts.de>
+     * Copyright (c) 2010-2015 Arne Blankerts <arne@blankerts.de>
      * All rights reserved.
      *
      * Redistribution and use in source and binary forms, with or without modification,
@@ -199,7 +199,4 @@ namespace TheSeer\phpDox\Collector {
 
     }
 
-    class MethodObjectException extends \Exception {
-        const InvalidVisibility = 1;
-    }
 }
