@@ -1,6 +1,6 @@
 <?php
     /**
-     * Copyright (c) 2010-2014 Arne Blankerts <arne@blankerts.de>
+     * Copyright (c) 2010-2015 Arne Blankerts <arne@blankerts.de>
      * All rights reserved.
      *
      * Redistribution and use in source and binary forms, with or without modification,
@@ -123,7 +123,7 @@ namespace TheSeer\phpDox\Collector {
             return $list;
         }
 
-        public function export() {
+        public function export($collapse = false) {
             if (count($this->collection) == 0) {
                 return $this->workDom;
             }
@@ -150,10 +150,13 @@ namespace TheSeer\phpDox\Collector {
             }
 
             $this->collection = array();
+
+            if ($collapse) {
+                $this->collapseDirectory();
+            }
             return $this->workDom;
         }
 
-
         private function importDirNode(fDOMElement $dir, $path) {
             $path .=  $dir->getAttribute('name');
             foreach($dir->query('phpdox:file') as $file) {
@@ -173,11 +176,20 @@ namespace TheSeer\phpDox\Collector {
             return $org->getAttribute('sha1') != $new->getAttribute('sha1');
         }
 
-    }
+        private function collapseDirectory() {
+            $first = $this->workDom->queryOne('/phpdox:source/phpdox:dir');
+            if ($first->query('phpdox:file')->length == 0 &&
+                $first->query('phpdox:dir')->length == 1) {
+                $dir = $first->queryOne('phpdox:dir');
+                foreach($dir->query('*') as $child) {
+                    $first->appendChild($child);
+                }
+                $first->setAttribute('name', $first->getAttribute('name') . '/' . $dir->getAttribute('name'));
+                $first->removeChild($dir);
+                $this->collapseDirectory();
+            }
+        }
 
-
-    class SourceCollectionException extends \Exception {
-        const SourceNotFound = 1;
     }
 
 }
