@@ -1,6 +1,6 @@
 <?php
     /**
-     * Copyright (c) 2010-2014 Arne Blankerts <arne@blankerts.de>
+     * Copyright (c) 2010-2015 Arne Blankerts <arne@blankerts.de>
      * All rights reserved.
      *
      * Redistribution and use in source and binary forms, with or without modification,
@@ -38,6 +38,15 @@ namespace TheSeer\phpDox\Collector {
 
     class TraitObject extends AbstractUnitObject {
         protected $rootName = 'trait';
+
+        public function addUser(AbstractUnitObject $unit) {
+            if ($this->getRootNode()->queryOne(sprintf('phpdox:users/phpdox:%s[@full = "%s"]', $unit->getType(), $unit->getName())) !== NULL) {
+                return;
+            }
+            $user = $this->addToContainer('users', $unit->getType());
+            $this->setName($unit->getName(), $user);
+        }
+
     }
 
 }
