@@ -18,6 +18,7 @@ namespace TheSeer\phpDox {
          * @return bool
          */
         public function exists() {
+            clearstatcache(true, $this->getPathname());
             return file_exists($this->getPathname());
         }
 
@@ -39,7 +40,7 @@ namespace TheSeer\phpDox {
             if ($inclusive) {
                 $relationPath = dirname($relationPath);
             }
-            $relPath = substr($relPath, strlen($relationPath)+1);
+            $relPath = mb_substr($relPath, mb_strlen($relationPath)+1);
             return new FileInfo($relPath);
         }
 
@@ -69,8 +70,4 @@ namespace TheSeer\phpDox {
 
     }
 
-    class FileInfoException extends \Exception {
-        const InvalidPath = 1;
-        const NotImplemented = 2;
-    }
 }
