@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright (c) 2010-2013 Arne Blankerts <arne@blankerts.de>
+ * Copyright (c) 2010-2015 Arne Blankerts <arne@blankerts.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without modification,
@@ -34,12 +34,9 @@
  * @copyright  Arne Blankerts <arne@blankerts.de>, All rights reserved.
  * @license    BSD License
  */
-
-namespace TheSeer\phpDox\Tests\Unit\DocBlock {
+namespace TheSeer\phpDox\DocBlock {
 
     use TheSeer\fDOM\fDOMDocument;
-    use TheSeer\phpDox\DocBlock\DocBlock;
-    use TheSeer\phpDox\DocBlock\GenericElement;
 
     /**
      * Class DocBlockTest
